IOWebSocket class

A dart-io-based WebSocket implementation.

Usable when targeting native platforms.

Implemented types

Constructors

IOWebSocket.fromWebSocket(WebSocket webSocket)
factory

Properties

events → Stream<WebSocketEvent>
A Stream of WebSocketEvent received from the peer.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
protocol → String
The WebSocket subprotocol negotiated with the peer.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close([int? code, String? reason]) → Future<void>
Closes the WebSocket connection and the events Stream.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendBytes(Uint8List b) → void
Sends binary data to the connected peer.
override
sendText(String s) → void
Sends text data to the connected peer.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

connect(Uri url, {Iterable<String>? protocols}) → Future<IOWebSocket>
Create a new WebSocket connection using dart:io WebSocket.
override